import io
from typing import Any

class UioStream:
    _s: Any
    _is_bin: Any
    def __init__(self, s, is_bin) -> None: ...
    def write(self, data, off: Any | None = ..., sz: Any | None = ...) -> None: ...
    def __getattr__(self, attr): ...
    def __iter__(self): ...
    def __enter__(self): ...
    def __exit__(self, *args): ...

class StringIO(io.StringIO):
    def __iadd__(self, s): ...

class BytesIO(io.BytesIO):
    def __iadd__(self, s): ...

def open(name, mode: str = ..., *args, **kw): ...



"""
Module: 'stm' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any

ADC1 = 1073815552  # type: int
ADC123_COMMON = 1073816320  # type: int
ADC2 = 1073815808  # type: int
ADC3 = 1073816064  # type: int
ADC_CR1 = 4  # type: int
ADC_CR2 = 8  # type: int
ADC_DR = 76  # type: int
ADC_HTR = 36  # type: int
ADC_JDR1 = 60  # type: int
ADC_JDR2 = 64  # type: int
ADC_JDR3 = 68  # type: int
ADC_JDR4 = 72  # type: int
ADC_JOFR1 = 20  # type: int
ADC_JOFR2 = 24  # type: int
ADC_JOFR3 = 28  # type: int
ADC_JOFR4 = 32  # type: int
ADC_JSQR = 56  # type: int
ADC_LTR = 40  # type: int
ADC_SMPR1 = 12  # type: int
ADC_SMPR2 = 16  # type: int
ADC_SQR1 = 44  # type: int
ADC_SQR2 = 48  # type: int
ADC_SQR3 = 52  # type: int
ADC_SR = 0  # type: int
CAN1 = 1073767424  # type: int
CAN2 = 1073768448  # type: int
CRC = 1073885184  # type: int
CRC_CR = 8  # type: int
CRC_DR = 0  # type: int
CRC_IDR = 4  # type: int
DAC = 1073771520  # type: int
DAC1 = 1073771520  # type: int
DAC_CR = 0  # type: int
DAC_DHR12L1 = 12  # type: int
DAC_DHR12L2 = 24  # type: int
DAC_DHR12LD = 36  # type: int
DAC_DHR12R1 = 8  # type: int
DAC_DHR12R2 = 20  # type: int
DAC_DHR12RD = 32  # type: int
DAC_DHR8R1 = 16  # type: int
DAC_DHR8R2 = 28  # type: int
DAC_DHR8RD = 40  # type: int
DAC_DOR1 = 44  # type: int
DAC_DOR2 = 48  # type: int
DAC_SR = 52  # type: int
DAC_SWTRIGR = 4  # type: int
DBGMCU = 3758366720  # type: int
DBGMCU_APB1FZ = 8  # type: int
DBGMCU_APB2FZ = 12  # type: int
DBGMCU_CR = 4  # type: int
DBGMCU_IDCODE = 0  # type: int
DMA1 = 1073897472  # type: int
DMA2 = 1073898496  # type: int
DMA_HIFCR = 12  # type: int
DMA_HISR = 4  # type: int
DMA_LIFCR = 8  # type: int
DMA_LISR = 0  # type: int
EXTI = 1073822720  # type: int
EXTI_EMR = 4  # type: int
EXTI_FTSR = 12  # type: int
EXTI_IMR = 0  # type: int
EXTI_PR = 20  # type: int
EXTI_RTSR = 8  # type: int
EXTI_SWIER = 16  # type: int
FLASH = 1073888256  # type: int
FLASH_ACR = 0  # type: int
FLASH_CR = 16  # type: int
FLASH_KEYR = 4  # type: int
FLASH_OPTCR = 20  # type: int
FLASH_OPTCR1 = 24  # type: int
FLASH_OPTKEYR = 8  # type: int
FLASH_SR = 12  # type: int
GPIOA = 1073872896  # type: int
GPIOB = 1073873920  # type: int
GPIOC = 1073874944  # type: int
GPIOD = 1073875968  # type: int
GPIOE = 1073876992  # type: int
GPIOF = 1073878016  # type: int
GPIOG = 1073879040  # type: int
GPIOH = 1073880064  # type: int
GPIOI = 1073881088  # type: int
GPIO_AFR0 = 32  # type: int
GPIO_AFR1 = 36  # type: int
GPIO_BSRR = 24  # type: int
GPIO_BSRRH = 26  # type: int
GPIO_BSRRL = 24  # type: int
GPIO_IDR = 16  # type: int
GPIO_LCKR = 28  # type: int
GPIO_MODER = 0  # type: int
GPIO_ODR = 20  # type: int
GPIO_OSPEEDR = 8  # type: int
GPIO_OTYPER = 4  # type: int
GPIO_PUPDR = 12  # type: int
I2C1 = 1073763328  # type: int
I2C2 = 1073764352  # type: int
I2C3 = 1073765376  # type: int
I2C_CCR = 28  # type: int
I2C_CR1 = 0  # type: int
I2C_CR2 = 4  # type: int
I2C_DR = 16  # type: int
I2C_OAR1 = 8  # type: int
I2C_OAR2 = 12  # type: int
I2C_SR1 = 20  # type: int
I2C_SR2 = 24  # type: int
I2C_TRISE = 32  # type: int
I2S2EXT = 1073755136  # type: int
I2S3EXT = 1073758208  # type: int
IWDG = 1073754112  # type: int
IWDG_KR = 0  # type: int
IWDG_PR = 4  # type: int
IWDG_RLR = 8  # type: int
IWDG_SR = 12  # type: int
PWR = 1073770496  # type: int
PWR_CR = 0  # type: int
PWR_CSR = 4  # type: int
RCC = 1073887232  # type: int
RCC_AHB1ENR = 48  # type: int
RCC_AHB1LPENR = 80  # type: int
RCC_AHB1RSTR = 16  # type: int
RCC_AHB2ENR = 52  # type: int
RCC_AHB2LPENR = 84  # type: int
RCC_AHB2RSTR = 20  # type: int
RCC_AHB3ENR = 56  # type: int
RCC_AHB3LPENR = 88  # type: int
RCC_AHB3RSTR = 24  # type: int
RCC_APB1ENR = 64  # type: int
RCC_APB1LPENR = 96  # type: int
RCC_APB1RSTR = 32  # type: int
RCC_APB2ENR = 68  # type: int
RCC_APB2LPENR = 100  # type: int
RCC_APB2RSTR = 36  # type: int
RCC_BDCR = 112  # type: int
RCC_CFGR = 8  # type: int
RCC_CIR = 12  # type: int
RCC_CR = 0  # type: int
RCC_CSR = 116  # type: int
RCC_PLLCFGR = 4  # type: int
RCC_PLLI2SCFGR = 132  # type: int
RCC_SSCGR = 128  # type: int
RNG = 1342572544  # type: int
RNG_CR = 0  # type: int
RNG_DR = 8  # type: int
RNG_SR = 4  # type: int
RTC = 1073752064  # type: int
RTC_ALRMAR = 28  # type: int
RTC_ALRMASSR = 68  # type: int
RTC_ALRMBR = 32  # type: int
RTC_ALRMBSSR = 72  # type: int
RTC_BKP0R = 80  # type: int
RTC_BKP10R = 120  # type: int
RTC_BKP11R = 124  # type: int
RTC_BKP12R = 128  # type: int
RTC_BKP13R = 132  # type: int
RTC_BKP14R = 136  # type: int
RTC_BKP15R = 140  # type: int
RTC_BKP16R = 144  # type: int
RTC_BKP17R = 148  # type: int
RTC_BKP18R = 152  # type: int
RTC_BKP19R = 156  # type: int
RTC_BKP1R = 84  # type: int
RTC_BKP2R = 88  # type: int
RTC_BKP3R = 92  # type: int
RTC_BKP4R = 96  # type: int
RTC_BKP5R = 100  # type: int
RTC_BKP6R = 104  # type: int
RTC_BKP7R = 108  # type: int
RTC_BKP8R = 112  # type: int
RTC_BKP9R = 116  # type: int
RTC_CALIBR = 24  # type: int
RTC_CALR = 60  # type: int
RTC_CR = 8  # type: int
RTC_DR = 4  # type: int
RTC_ISR = 12  # type: int
RTC_PRER = 16  # type: int
RTC_SHIFTR = 44  # type: int
RTC_SSR = 40  # type: int
RTC_TAFCR = 64  # type: int
RTC_TR = 0  # type: int
RTC_TSDR = 52  # type: int
RTC_TSSSR = 56  # type: int
RTC_TSTR = 48  # type: int
RTC_WPR = 36  # type: int
RTC_WUTR = 20  # type: int
SDIO = 1073818624  # type: int
SPI1 = 1073819648  # type: int
SPI2 = 1073756160  # type: int
SPI3 = 1073757184  # type: int
SPI_CR1 = 0  # type: int
SPI_CR2 = 4  # type: int
SPI_CRCPR = 16  # type: int
SPI_DR = 12  # type: int
SPI_I2SCFGR = 28  # type: int
SPI_I2SPR = 32  # type: int
SPI_RXCRCR = 20  # type: int
SPI_SR = 8  # type: int
SPI_TXCRCR = 24  # type: int
SYSCFG = 1073821696  # type: int
SYSCFG_CMPCR = 32  # type: int
SYSCFG_EXTICR0 = 8  # type: int
SYSCFG_EXTICR1 = 12  # type: int
SYSCFG_EXTICR2 = 16  # type: int
SYSCFG_EXTICR3 = 20  # type: int
SYSCFG_MEMRMP = 0  # type: int
SYSCFG_PMC = 4  # type: int
TIM1 = 1073807360  # type: int
TIM10 = 1073824768  # type: int
TIM11 = 1073825792  # type: int
TIM12 = 1073747968  # type: int
TIM13 = 1073748992  # type: int
TIM14 = 1073750016  # type: int
TIM2 = 1073741824  # type: int
TIM3 = 1073742848  # type: int
TIM4 = 1073743872  # type: int
TIM5 = 1073744896  # type: int
TIM6 = 1073745920  # type: int
TIM7 = 1073746944  # type: int
TIM8 = 1073808384  # type: int
TIM9 = 1073823744  # type: int
TIM_ARR = 44  # type: int
TIM_BDTR = 68  # type: int
TIM_CCER = 32  # type: int
TIM_CCMR1 = 24  # type: int
TIM_CCMR2 = 28  # type: int
TIM_CCR1 = 52  # type: int
TIM_CCR2 = 56  # type: int
TIM_CCR3 = 60  # type: int
TIM_CCR4 = 64  # type: int
TIM_CNT = 36  # type: int
TIM_CR1 = 0  # type: int
TIM_CR2 = 4  # type: int
TIM_DCR = 72  # type: int
TIM_DIER = 12  # type: int
TIM_DMAR = 76  # type: int
TIM_EGR = 20  # type: int
TIM_OR = 80  # type: int
TIM_PSC = 40  # type: int
TIM_RCR = 48  # type: int
TIM_SMCR = 8  # type: int
TIM_SR = 16  # type: int
UART4 = 1073761280  # type: int
UART5 = 1073762304  # type: int
USART1 = 1073811456  # type: int
USART2 = 1073759232  # type: int
USART3 = 1073760256  # type: int
USART6 = 1073812480  # type: int
USART_BRR = 8  # type: int
USART_CR1 = 12  # type: int
USART_CR2 = 16  # type: int
USART_CR3 = 20  # type: int
USART_DR = 4  # type: int
USART_GTPR = 24  # type: int
USART_SR = 0  # type: int
WWDG = 1073753088  # type: int
WWDG_CFR = 4  # type: int
WWDG_CR = 0  # type: int
WWDG_SR = 8  # type: int
mem16: Any  ## <class 'mem'> = <16-bit memory>
mem32: Any  ## <class 'mem'> = <32-bit memory>
mem8: Any  ## <class 'mem'> = <8-bit memory>



from typing import Any

def open(*args, **kwargs) -> Any: ...

class BytesIO:
    def __init__(self, *argv, **kwargs) -> None: ...
    def close(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def flush(self, *args, **kwargs) -> Any: ...
    def getvalue(self, *args, **kwargs) -> Any: ...
    def seek(self, *args, **kwargs) -> Any: ...
    def tell(self, *args, **kwargs) -> Any: ...

class FileIO:
    def __init__(self, *argv, **kwargs) -> None: ...
    def close(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def flush(self, *args, **kwargs) -> Any: ...
    def readlines(self, *args, **kwargs) -> Any: ...
    def seek(self, *args, **kwargs) -> Any: ...
    def tell(self, *args, **kwargs) -> Any: ...

class IOBase:
    def __init__(self, *argv, **kwargs) -> None: ...

class StringIO:
    def __init__(self, *argv, **kwargs) -> None: ...
    def close(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def flush(self, *args, **kwargs) -> Any: ...
    def getvalue(self, *args, **kwargs) -> Any: ...
    def seek(self, *args, **kwargs) -> Any: ...
    def tell(self, *args, **kwargs) -> Any: ...

class TextIOWrapper:
    def __init__(self, *argv, **kwargs) -> None: ...
    def close(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def flush(self, *args, **kwargs) -> Any: ...
    def readlines(self, *args, **kwargs) -> Any: ...
    def seek(self, *args, **kwargs) -> Any: ...
    def tell(self, *args, **kwargs) -> Any: ...



"""
Module: 'framebuf' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


class FrameBuffer:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def blit(self, *args, **kwargs) -> Any:
        ...

    def fill(self, *args, **kwargs) -> Any:
        ...

    def fill_rect(self, *args, **kwargs) -> Any:
        ...

    def hline(self, *args, **kwargs) -> Any:
        ...

    def line(self, *args, **kwargs) -> Any:
        ...

    def pixel(self, *args, **kwargs) -> Any:
        ...

    def rect(self, *args, **kwargs) -> Any:
        ...

    def scroll(self, *args, **kwargs) -> Any:
        ...

    def text(self, *args, **kwargs) -> Any:
        ...

    def vline(self, *args, **kwargs) -> Any:
        ...


def FrameBuffer1(*args, **kwargs) -> Any:
    ...


GS2_HMSB = 5  # type: int
GS4_HMSB = 2  # type: int
GS8 = 6  # type: int
MONO_HLSB = 3  # type: int
MONO_HMSB = 4  # type: int
MONO_VLSB = 0  # type: int
MVLSB = 0  # type: int
RGB565 = 1  # type: int



from token import *
from collections.abc import Generator
from typing import Any

COMMENT: Any
NL: Any
ENCODING: Any

class TokenInfo:
    def __str__(self): ...

def get_indent(l): ...
def get_str(l, readline): ...
def tokenize(readline) -> Generator[Any, None, None]: ...



import heapq
from utime import ticks_diff


class Entry:
    def __init__(self, time, obj, userdata):
        self.time = time
        self.obj = obj
        self.userdata = userdata

    def __lt__(self, another):
        return ticks_diff(self.time, another.time) < 0


class utimeq:
    def __init__(self, sz):
        self.heap = []
        self.max_sz = sz

    def __bool__(self):
        return bool(self.heap)

    def push(self, time, obj, userdata):
        e = Entry(time, obj, userdata)
        heapq.heappush(self.heap, e)
        return id(e)

    def pop(self, arr):
        e = heapq.heappop(self.heap)
        arr[0] = e.time
        arr[1] = e.obj
        arr[2] = e.userdata

    def peektime(self):
        return self.heap[0].time

    def remove(self, id):
        raise NotImplementedError



from typing import Any

def cos(*args, **kwargs) -> Any: ...

e: float

def exp(*args, **kwargs) -> Any: ...
def log(*args, **kwargs) -> Any: ...
def log10(*args, **kwargs) -> Any: ...
def phase(*args, **kwargs) -> Any: ...

pi: float

def polar(*args, **kwargs) -> Any: ...
def rect(*args, **kwargs) -> Any: ...
def sin(*args, **kwargs) -> Any: ...
def sqrt(*args, **kwargs) -> Any: ...



"""
Module: 'pyb' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


def main(*args, **kwargs) -> Any:
    ...


def stop(*args, **kwargs) -> Any:
    ...


SD: Any  ## <class 'SDCard'> = <SDCard>


class DAC:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    CIRCULAR = 256  # type: int
    NORMAL = 0  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def noise(self, *args, **kwargs) -> Any:
        ...

    def triangle(self, *args, **kwargs) -> Any:
        ...

    def write_timed(self, *args, **kwargs) -> Any:
        ...


class RTC:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def calibration(self, *args, **kwargs) -> Any:
        ...

    def datetime(self, *args, **kwargs) -> Any:
        ...

    def info(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def wakeup(self, *args, **kwargs) -> Any:
        ...


class ADC:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def read_timed(self, *args, **kwargs) -> Any:
        ...

    def read_timed_multi(self, *args, **kwargs) -> Any:
        ...


class ADCAll:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read_channel(self, *args, **kwargs) -> Any:
        ...

    def read_core_temp(self, *args, **kwargs) -> Any:
        ...

    def read_core_vbat(self, *args, **kwargs) -> Any:
        ...

    def read_core_vref(self, *args, **kwargs) -> Any:
        ...

    def read_vref(self, *args, **kwargs) -> Any:
        ...


class Accel:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    def filtered_xyz(self, *args, **kwargs) -> Any:
        ...

    def tilt(self, *args, **kwargs) -> Any:
        ...

    def x(self, *args, **kwargs) -> Any:
        ...

    def y(self, *args, **kwargs) -> Any:
        ...

    def z(self, *args, **kwargs) -> Any:
        ...


class CAN:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def any(self, *args, **kwargs) -> Any:
        ...

    def send(self, *args, **kwargs) -> Any:
        ...

    BUS_OFF = 4  # type: int
    ERROR_ACTIVE = 1  # type: int
    ERROR_PASSIVE = 3  # type: int
    ERROR_WARNING = 2  # type: int
    LIST16 = 1  # type: int
    LIST32 = 3  # type: int
    LOOPBACK = 67108864  # type: int
    MASK16 = 0  # type: int
    MASK32 = 2  # type: int
    NORMAL = 0  # type: int
    SILENT = 134217728  # type: int
    SILENT_LOOPBACK = 201326592  # type: int
    STOPPED = 0  # type: int

    def clearfilter(self, *args, **kwargs) -> Any:
        ...

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def info(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    @classmethod
    def initfilterbanks(cls, *args, **kwargs) -> Any:
        ...

    def recv(self, *args, **kwargs) -> Any:
        ...

    def restart(self, *args, **kwargs) -> Any:
        ...

    def rxcallback(self, *args, **kwargs) -> Any:
        ...

    def setfilter(self, *args, **kwargs) -> Any:
        ...

    def state(self, *args, **kwargs) -> Any:
        ...


class ExtInt:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    EVT_FALLING = 270663680  # type: int
    EVT_RISING = 269615104  # type: int
    EVT_RISING_FALLING = 271712256  # type: int
    IRQ_FALLING = 270598144  # type: int
    IRQ_RISING = 269549568  # type: int
    IRQ_RISING_FALLING = 271646720  # type: int

    def disable(self, *args, **kwargs) -> Any:
        ...

    def enable(self, *args, **kwargs) -> Any:
        ...

    def line(self, *args, **kwargs) -> Any:
        ...

    def regs(self, *args, **kwargs) -> Any:
        ...

    def swint(self, *args, **kwargs) -> Any:
        ...


class Flash:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def ioctl(self, *args, **kwargs) -> Any:
        ...

    def readblocks(self, *args, **kwargs) -> Any:
        ...

    def writeblocks(self, *args, **kwargs) -> Any:
        ...


class I2C:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def send(self, *args, **kwargs) -> Any:
        ...

    CONTROLLER = 0  # type: int
    MASTER = 0  # type: int
    PERIPHERAL = 1  # type: int
    SLAVE = 1  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def is_ready(self, *args, **kwargs) -> Any:
        ...

    def mem_read(self, *args, **kwargs) -> Any:
        ...

    def mem_write(self, *args, **kwargs) -> Any:
        ...

    def recv(self, *args, **kwargs) -> Any:
        ...

    def scan(self, *args, **kwargs) -> Any:
        ...


class LCD:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def get(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    def command(self, *args, **kwargs) -> Any:
        ...

    def contrast(self, *args, **kwargs) -> Any:
        ...

    def fill(self, *args, **kwargs) -> Any:
        ...

    def light(self, *args, **kwargs) -> Any:
        ...

    def pixel(self, *args, **kwargs) -> Any:
        ...

    def show(self, *args, **kwargs) -> Any:
        ...

    def text(self, *args, **kwargs) -> Any:
        ...


class LED:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def intensity(self, *args, **kwargs) -> Any:
        ...

    def off(self, *args, **kwargs) -> Any:
        ...

    def on(self, *args, **kwargs) -> Any:
        ...

    def toggle(self, *args, **kwargs) -> Any:
        ...


class Pin:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    @classmethod
    def dict(cls, *args, **kwargs) -> Any:
        ...

    def value(self, *args, **kwargs) -> Any:
        ...

    AF1_TIM1 = 1  # type: int
    AF1_TIM2 = 1  # type: int
    AF2_TIM3 = 2  # type: int
    AF2_TIM4 = 2  # type: int
    AF2_TIM5 = 2  # type: int
    AF3_TIM10 = 3  # type: int
    AF3_TIM11 = 3  # type: int
    AF3_TIM8 = 3  # type: int
    AF3_TIM9 = 3  # type: int
    AF4_I2C1 = 4  # type: int
    AF4_I2C2 = 4  # type: int
    AF5_I2S2 = 5  # type: int
    AF5_SPI1 = 5  # type: int
    AF5_SPI2 = 5  # type: int
    AF6_I2S2 = 6  # type: int
    AF7_USART1 = 7  # type: int
    AF7_USART2 = 7  # type: int
    AF7_USART3 = 7  # type: int
    AF8_UART4 = 8  # type: int
    AF8_USART6 = 8  # type: int
    AF9_CAN1 = 9  # type: int
    AF9_CAN2 = 9  # type: int
    AF9_TIM12 = 9  # type: int
    AF9_TIM13 = 9  # type: int
    AF9_TIM14 = 9  # type: int
    AF_OD = 18  # type: int
    AF_PP = 2  # type: int
    ALT = 2  # type: int
    ALT_OPEN_DRAIN = 18  # type: int
    ANALOG = 3  # type: int
    IN = 0  # type: int
    IRQ_FALLING = 270598144  # type: int
    IRQ_RISING = 269549568  # type: int
    OPEN_DRAIN = 17  # type: int
    OUT = 1  # type: int
    OUT_OD = 17  # type: int
    OUT_PP = 1  # type: int
    PULL_DOWN = 2  # type: int
    PULL_NONE = 0  # type: int
    PULL_UP = 1  # type: int

    def af(self, *args, **kwargs) -> Any:
        ...

    def af_list(self, *args, **kwargs) -> Any:
        ...

    class board:
        """"""

        def __init__(self, *argv, **kwargs) -> None:
            """"""
            ...

        LED_BLUE: Any  ## <class 'Pin'> = Pin(Pin.cpu.B4, mode=Pin.OUT)
        LED_GREEN: Any  ## <class 'Pin'> = Pin(Pin.cpu.A14, mode=Pin.OUT)
        LED_RED: Any  ## <class 'Pin'> = Pin(Pin.cpu.A13, mode=Pin.OUT)
        LED_YELLOW: Any  ## <class 'Pin'> = Pin(Pin.cpu.A15, mode=Pin.OUT)
        MMA_AVDD: Any  ## <class 'Pin'> = Pin(Pin.cpu.B5, mode=Pin.OUT)
        MMA_INT: Any  ## <class 'Pin'> = Pin(Pin.cpu.B2, mode=Pin.IN)
        SD: Any  ## <class 'Pin'> = Pin(Pin.cpu.A8, mode=Pin.IN, pull=Pin.PULL_UP)
        SD_CK: Any  ## <class 'Pin'> = Pin(Pin.cpu.C12, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        SD_CMD: Any  ## <class 'Pin'> = Pin(Pin.cpu.D2, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        SD_D0: Any  ## <class 'Pin'> = Pin(Pin.cpu.C8, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        SD_D1: Any  ## <class 'Pin'> = Pin(Pin.cpu.C9, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        SD_D2: Any  ## <class 'Pin'> = Pin(Pin.cpu.C10, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        SD_D3: Any  ## <class 'Pin'> = Pin(Pin.cpu.C11, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        SD_SW: Any  ## <class 'Pin'> = Pin(Pin.cpu.A8, mode=Pin.IN, pull=Pin.PULL_UP)
        SW: Any  ## <class 'Pin'> = Pin(Pin.cpu.B3, mode=Pin.IN, pull=Pin.PULL_UP)
        USB_DM: Any  ## <class 'Pin'> = Pin(Pin.cpu.A11, mode=Pin.ALT, af=10)
        USB_DP: Any  ## <class 'Pin'> = Pin(Pin.cpu.A12, mode=Pin.ALT, af=10)
        USB_ID: Any  ## <class 'Pin'> = Pin(Pin.cpu.A10, mode=Pin.ALT_OPEN_DRAIN, pull=Pin.PULL_UP, af=10)
        USB_VBUS: Any  ## <class 'Pin'> = Pin(Pin.cpu.A9, mode=Pin.IN)
        X1: Any  ## <class 'Pin'> = Pin(Pin.cpu.A0, mode=Pin.IN)
        X10: Any  ## <class 'Pin'> = Pin(Pin.cpu.B7, mode=Pin.IN)
        X11: Any  ## <class 'Pin'> = Pin(Pin.cpu.C4, mode=Pin.IN)
        X12: Any  ## <class 'Pin'> = Pin(Pin.cpu.C5, mode=Pin.IN)
        X17: Any  ## <class 'Pin'> = Pin(Pin.cpu.B3, mode=Pin.IN, pull=Pin.PULL_UP)
        X18: Any  ## <class 'Pin'> = Pin(Pin.cpu.C13, mode=Pin.IN)
        X19: Any  ## <class 'Pin'> = Pin(Pin.cpu.C0, mode=Pin.IN)
        X2: Any  ## <class 'Pin'> = Pin(Pin.cpu.A1, mode=Pin.IN)
        X20: Any  ## <class 'Pin'> = Pin(Pin.cpu.C1, mode=Pin.IN)
        X21: Any  ## <class 'Pin'> = Pin(Pin.cpu.C2, mode=Pin.IN)
        X22: Any  ## <class 'Pin'> = Pin(Pin.cpu.C3, mode=Pin.IN)
        X3: Any  ## <class 'Pin'> = Pin(Pin.cpu.A2, mode=Pin.IN)
        X4: Any  ## <class 'Pin'> = Pin(Pin.cpu.A3, mode=Pin.IN)
        X5: Any  ## <class 'Pin'> = Pin(Pin.cpu.A4, mode=Pin.IN)
        X6: Any  ## <class 'Pin'> = Pin(Pin.cpu.A5, mode=Pin.IN)
        X7: Any  ## <class 'Pin'> = Pin(Pin.cpu.A6, mode=Pin.IN)
        X8: Any  ## <class 'Pin'> = Pin(Pin.cpu.A7, mode=Pin.IN)
        X9: Any  ## <class 'Pin'> = Pin(Pin.cpu.B6, mode=Pin.IN)
        Y1: Any  ## <class 'Pin'> = Pin(Pin.cpu.C6, mode=Pin.IN)
        Y10: Any  ## <class 'Pin'> = Pin(Pin.cpu.B11, mode=Pin.IN)
        Y11: Any  ## <class 'Pin'> = Pin(Pin.cpu.B0, mode=Pin.IN)
        Y12: Any  ## <class 'Pin'> = Pin(Pin.cpu.B1, mode=Pin.IN)
        Y2: Any  ## <class 'Pin'> = Pin(Pin.cpu.C7, mode=Pin.IN)
        Y3: Any  ## <class 'Pin'> = Pin(Pin.cpu.B8, mode=Pin.IN)
        Y4: Any  ## <class 'Pin'> = Pin(Pin.cpu.B9, mode=Pin.IN)
        Y5: Any  ## <class 'Pin'> = Pin(Pin.cpu.B12, mode=Pin.IN)
        Y6: Any  ## <class 'Pin'> = Pin(Pin.cpu.B13, mode=Pin.IN)
        Y7: Any  ## <class 'Pin'> = Pin(Pin.cpu.B14, mode=Pin.IN)
        Y8: Any  ## <class 'Pin'> = Pin(Pin.cpu.B15, mode=Pin.IN)
        Y9: Any  ## <class 'Pin'> = Pin(Pin.cpu.B10, mode=Pin.IN)

    class cpu:
        """"""

        def __init__(self, *argv, **kwargs) -> None:
            """"""
            ...

        A0: Any  ## <class 'Pin'> = Pin(Pin.cpu.A0, mode=Pin.IN)
        A1: Any  ## <class 'Pin'> = Pin(Pin.cpu.A1, mode=Pin.IN)
        A10: Any  ## <class 'Pin'> = Pin(Pin.cpu.A10, mode=Pin.ALT_OPEN_DRAIN, pull=Pin.PULL_UP, af=10)
        A11: Any  ## <class 'Pin'> = Pin(Pin.cpu.A11, mode=Pin.ALT, af=10)
        A12: Any  ## <class 'Pin'> = Pin(Pin.cpu.A12, mode=Pin.ALT, af=10)
        A13: Any  ## <class 'Pin'> = Pin(Pin.cpu.A13, mode=Pin.OUT)
        A14: Any  ## <class 'Pin'> = Pin(Pin.cpu.A14, mode=Pin.OUT)
        A15: Any  ## <class 'Pin'> = Pin(Pin.cpu.A15, mode=Pin.OUT)
        A2: Any  ## <class 'Pin'> = Pin(Pin.cpu.A2, mode=Pin.IN)
        A3: Any  ## <class 'Pin'> = Pin(Pin.cpu.A3, mode=Pin.IN)
        A4: Any  ## <class 'Pin'> = Pin(Pin.cpu.A4, mode=Pin.IN)
        A5: Any  ## <class 'Pin'> = Pin(Pin.cpu.A5, mode=Pin.IN)
        A6: Any  ## <class 'Pin'> = Pin(Pin.cpu.A6, mode=Pin.IN)
        A7: Any  ## <class 'Pin'> = Pin(Pin.cpu.A7, mode=Pin.IN)
        A8: Any  ## <class 'Pin'> = Pin(Pin.cpu.A8, mode=Pin.IN, pull=Pin.PULL_UP)
        A9: Any  ## <class 'Pin'> = Pin(Pin.cpu.A9, mode=Pin.IN)
        B0: Any  ## <class 'Pin'> = Pin(Pin.cpu.B0, mode=Pin.IN)
        B1: Any  ## <class 'Pin'> = Pin(Pin.cpu.B1, mode=Pin.IN)
        B10: Any  ## <class 'Pin'> = Pin(Pin.cpu.B10, mode=Pin.IN)
        B11: Any  ## <class 'Pin'> = Pin(Pin.cpu.B11, mode=Pin.IN)
        B12: Any  ## <class 'Pin'> = Pin(Pin.cpu.B12, mode=Pin.IN)
        B13: Any  ## <class 'Pin'> = Pin(Pin.cpu.B13, mode=Pin.IN)
        B14: Any  ## <class 'Pin'> = Pin(Pin.cpu.B14, mode=Pin.IN)
        B15: Any  ## <class 'Pin'> = Pin(Pin.cpu.B15, mode=Pin.IN)
        B2: Any  ## <class 'Pin'> = Pin(Pin.cpu.B2, mode=Pin.IN)
        B3: Any  ## <class 'Pin'> = Pin(Pin.cpu.B3, mode=Pin.IN, pull=Pin.PULL_UP)
        B4: Any  ## <class 'Pin'> = Pin(Pin.cpu.B4, mode=Pin.OUT)
        B5: Any  ## <class 'Pin'> = Pin(Pin.cpu.B5, mode=Pin.OUT)
        B6: Any  ## <class 'Pin'> = Pin(Pin.cpu.B6, mode=Pin.IN)
        B7: Any  ## <class 'Pin'> = Pin(Pin.cpu.B7, mode=Pin.IN)
        B8: Any  ## <class 'Pin'> = Pin(Pin.cpu.B8, mode=Pin.IN)
        B9: Any  ## <class 'Pin'> = Pin(Pin.cpu.B9, mode=Pin.IN)
        C0: Any  ## <class 'Pin'> = Pin(Pin.cpu.C0, mode=Pin.IN)
        C1: Any  ## <class 'Pin'> = Pin(Pin.cpu.C1, mode=Pin.IN)
        C10: Any  ## <class 'Pin'> = Pin(Pin.cpu.C10, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        C11: Any  ## <class 'Pin'> = Pin(Pin.cpu.C11, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        C12: Any  ## <class 'Pin'> = Pin(Pin.cpu.C12, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        C13: Any  ## <class 'Pin'> = Pin(Pin.cpu.C13, mode=Pin.IN)
        C2: Any  ## <class 'Pin'> = Pin(Pin.cpu.C2, mode=Pin.IN)
        C3: Any  ## <class 'Pin'> = Pin(Pin.cpu.C3, mode=Pin.IN)
        C4: Any  ## <class 'Pin'> = Pin(Pin.cpu.C4, mode=Pin.IN)
        C5: Any  ## <class 'Pin'> = Pin(Pin.cpu.C5, mode=Pin.IN)
        C6: Any  ## <class 'Pin'> = Pin(Pin.cpu.C6, mode=Pin.IN)
        C7: Any  ## <class 'Pin'> = Pin(Pin.cpu.C7, mode=Pin.IN)
        C8: Any  ## <class 'Pin'> = Pin(Pin.cpu.C8, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        C9: Any  ## <class 'Pin'> = Pin(Pin.cpu.C9, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)
        D2: Any  ## <class 'Pin'> = Pin(Pin.cpu.D2, mode=Pin.ALT, pull=Pin.PULL_UP, af=12)

    @classmethod
    def debug(cls, *args, **kwargs) -> Any:
        ...

    def gpio(self, *args, **kwargs) -> Any:
        ...

    def high(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def irq(self, *args, **kwargs) -> Any:
        ...

    def low(self, *args, **kwargs) -> Any:
        ...

    @classmethod
    def mapper(cls, *args, **kwargs) -> Any:
        ...

    def mode(self, *args, **kwargs) -> Any:
        ...

    def name(self, *args, **kwargs) -> Any:
        ...

    def names(self, *args, **kwargs) -> Any:
        ...

    def off(self, *args, **kwargs) -> Any:
        ...

    def on(self, *args, **kwargs) -> Any:
        ...

    def pin(self, *args, **kwargs) -> Any:
        ...

    def port(self, *args, **kwargs) -> Any:
        ...

    def pull(self, *args, **kwargs) -> Any:
        ...


class SDCard:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    def info(self, *args, **kwargs) -> Any:
        ...

    def ioctl(self, *args, **kwargs) -> Any:
        ...

    def power(self, *args, **kwargs) -> Any:
        ...

    def present(self, *args, **kwargs) -> Any:
        ...

    def readblocks(self, *args, **kwargs) -> Any:
        ...

    def writeblocks(self, *args, **kwargs) -> Any:
        ...


class SPI:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def send(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    CONTROLLER = 260  # type: int
    LSB = 128  # type: int
    MASTER = 260  # type: int
    MSB = 0  # type: int
    PERIPHERAL = 0  # type: int
    SLAVE = 0  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def recv(self, *args, **kwargs) -> Any:
        ...

    def send_recv(self, *args, **kwargs) -> Any:
        ...

    def write_readinto(self, *args, **kwargs) -> Any:
        ...


class Servo:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def angle(self, *args, **kwargs) -> Any:
        ...

    def calibration(self, *args, **kwargs) -> Any:
        ...

    def pulse_width(self, *args, **kwargs) -> Any:
        ...

    def speed(self, *args, **kwargs) -> Any:
        ...


class Switch:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def value(self, *args, **kwargs) -> Any:
        ...

    def callback(self, *args, **kwargs) -> Any:
        ...


class Timer:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    BOTH = 10  # type: int
    BRK_HIGH = 2  # type: int
    BRK_LOW = 1  # type: int
    BRK_OFF = 0  # type: int
    CENTER = 32  # type: int
    DOWN = 16  # type: int
    ENC_A = 9  # type: int
    ENC_AB = 11  # type: int
    ENC_B = 10  # type: int
    FALLING = 2  # type: int
    HIGH = 0  # type: int
    IC = 8  # type: int
    LOW = 2  # type: int
    OC_ACTIVE = 3  # type: int
    OC_FORCED_ACTIVE = 6  # type: int
    OC_FORCED_INACTIVE = 7  # type: int
    OC_INACTIVE = 4  # type: int
    OC_TIMING = 2  # type: int
    OC_TOGGLE = 5  # type: int
    PWM = 0  # type: int
    PWM_INVERTED = 1  # type: int
    RISING = 0  # type: int
    UP = 0  # type: int

    def callback(self, *args, **kwargs) -> Any:
        ...

    def channel(self, *args, **kwargs) -> Any:
        ...

    def counter(self, *args, **kwargs) -> Any:
        ...

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def freq(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def period(self, *args, **kwargs) -> Any:
        ...

    def prescaler(self, *args, **kwargs) -> Any:
        ...

    def source_freq(self, *args, **kwargs) -> Any:
        ...


class UART:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def any(self, *args, **kwargs) -> Any:
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def readline(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    CTS = 512  # type: int
    IRQ_RXIDLE = 16  # type: int
    RTS = 256  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def irq(self, *args, **kwargs) -> Any:
        ...

    def readchar(self, *args, **kwargs) -> Any:
        ...

    def sendbreak(self, *args, **kwargs) -> Any:
        ...

    def writechar(self, *args, **kwargs) -> Any:
        ...


class USB_HID:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def send(self, *args, **kwargs) -> Any:
        ...

    def recv(self, *args, **kwargs) -> Any:
        ...


class USB_VCP:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def any(self, *args, **kwargs) -> Any:
        ...

    def close(self, *args, **kwargs) -> Any:
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def readline(self, *args, **kwargs) -> Any:
        ...

    def send(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    CTS = 2  # type: int
    IRQ_RX = 1  # type: int
    RTS = 1  # type: int

    def init(self, *args, **kwargs) -> Any:
        ...

    def irq(self, *args, **kwargs) -> Any:
        ...

    def isconnected(self, *args, **kwargs) -> Any:
        ...

    def readlines(self, *args, **kwargs) -> Any:
        ...

    def recv(self, *args, **kwargs) -> Any:
        ...

    def setinterrupt(self, *args, **kwargs) -> Any:
        ...


def bootloader(*args, **kwargs) -> Any:
    ...


def country(*args, **kwargs) -> Any:
    ...


def delay(*args, **kwargs) -> Any:
    ...


def dht_readinto(*args, **kwargs) -> Any:
    ...


def disable_irq(*args, **kwargs) -> Any:
    ...


def elapsed_micros(*args, **kwargs) -> Any:
    ...


def elapsed_millis(*args, **kwargs) -> Any:
    ...


def enable_irq(*args, **kwargs) -> Any:
    ...


def fault_debug(*args, **kwargs) -> Any:
    ...


def freq(*args, **kwargs) -> Any:
    ...


def hard_reset(*args, **kwargs) -> Any:
    ...


def have_cdc(*args, **kwargs) -> Any:
    ...


def hid(*args, **kwargs) -> Any:
    ...


hid_keyboard = ()  # type: tuple
hid_mouse = ()  # type: tuple


def info(*args, **kwargs) -> Any:
    ...


def micros(*args, **kwargs) -> Any:
    ...


def millis(*args, **kwargs) -> Any:
    ...


def mount(*args, **kwargs) -> Any:
    ...


def pwm(*args, **kwargs) -> Any:
    ...


def repl_info(*args, **kwargs) -> Any:
    ...


def repl_uart(*args, **kwargs) -> Any:
    ...


def rng(*args, **kwargs) -> Any:
    ...


def servo(*args, **kwargs) -> Any:
    ...


def standby(*args, **kwargs) -> Any:
    ...


def sync(*args, **kwargs) -> Any:
    ...


def udelay(*args, **kwargs) -> Any:
    ...


def unique_id(*args, **kwargs) -> Any:
    ...


def usb_mode(*args, **kwargs) -> Any:
    ...


def wfi(*args, **kwargs) -> Any:
    ...



"""
Module: 'struct' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


def calcsize(*args, **kwargs) -> Any:
    ...


def pack(*args, **kwargs) -> Any:
    ...


def pack_into(*args, **kwargs) -> Any:
    ...


def unpack(*args, **kwargs) -> Any:
    ...


def unpack_from(*args, **kwargs) -> Any:
    ...



from typing import Any

class Func:
    f: Any
    restype: Any
    def __init__(self, f, restype) -> None: ...
    def __call__(self, *args): ...

class Var:
    v: Any
    def __init__(self, v) -> None: ...
    def get(self): ...

class DynMod:
    typemap: Any
    mod: Any
    def __init__(self, name) -> None: ...
    def func(self, ret, name, params): ...
    def var(self, type, name): ...

def open(name): ...
def func(ret, addr, params): ...
def callback(ret, func, params): ...



from typing import Any

class FrameBuffer:
    def __init__(self, *argv, **kwargs) -> None: ...
    def blit(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def fill_rect(self, *args, **kwargs) -> Any: ...
    def hline(self, *args, **kwargs) -> Any: ...
    def line(self, *args, **kwargs) -> Any: ...
    def pixel(self, *args, **kwargs) -> Any: ...
    def rect(self, *args, **kwargs) -> Any: ...
    def scroll(self, *args, **kwargs) -> Any: ...
    def text(self, *args, **kwargs) -> Any: ...
    def vline(self, *args, **kwargs) -> Any: ...

def FrameBuffer1(*args, **kwargs) -> Any: ...

GS2_HMSB: int
GS4_HMSB: int
GS8: int
MONO_HLSB: int
MONO_HMSB: int
MONO_VLSB: int
MVLSB: int
RGB565: int



from typing import Any

def a2b_base64(*args, **kwargs) -> Any: ...
def b2a_base64(*args, **kwargs) -> Any: ...
def crc32(*args, **kwargs) -> Any: ...
def hexlify(*args, **kwargs) -> Any: ...
def unhexlify(*args, **kwargs) -> Any: ...



from typing import Any

def main(*args, **kwargs) -> Any: ...
def stop(*args, **kwargs) -> Any: ...

SD: Any

class DAC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def write(self, *args, **kwargs) -> Any: ...
    CIRCULAR: int
    NORMAL: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def noise(self, *args, **kwargs) -> Any: ...
    def triangle(self, *args, **kwargs) -> Any: ...
    def write_timed(self, *args, **kwargs) -> Any: ...

class RTC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def calibration(self, *args, **kwargs) -> Any: ...
    def datetime(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def wakeup(self, *args, **kwargs) -> Any: ...

class ADC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def read_timed(self, *args, **kwargs) -> Any: ...
    def read_timed_multi(self, *args, **kwargs) -> Any: ...

class ADCAll:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read_channel(self, *args, **kwargs) -> Any: ...
    def read_core_temp(self, *args, **kwargs) -> Any: ...
    def read_core_vbat(self, *args, **kwargs) -> Any: ...
    def read_core_vref(self, *args, **kwargs) -> Any: ...
    def read_vref(self, *args, **kwargs) -> Any: ...

class Accel:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def filtered_xyz(self, *args, **kwargs) -> Any: ...
    def tilt(self, *args, **kwargs) -> Any: ...
    def x(self, *args, **kwargs) -> Any: ...
    def y(self, *args, **kwargs) -> Any: ...
    def z(self, *args, **kwargs) -> Any: ...

class CAN:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def send(self, *args, **kwargs) -> Any: ...
    BUS_OFF: int
    ERROR_ACTIVE: int
    ERROR_PASSIVE: int
    ERROR_WARNING: int
    LIST16: int
    LIST32: int
    LOOPBACK: int
    MASK16: int
    MASK32: int
    NORMAL: int
    SILENT: int
    SILENT_LOOPBACK: int
    STOPPED: int
    def clearfilter(self, *args, **kwargs) -> Any: ...
    def deinit(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    @classmethod
    def initfilterbanks(cls, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def restart(self, *args, **kwargs) -> Any: ...
    def rxcallback(self, *args, **kwargs) -> Any: ...
    def setfilter(self, *args, **kwargs) -> Any: ...
    def state(self, *args, **kwargs) -> Any: ...

class ExtInt:
    def __init__(self, *argv, **kwargs) -> None: ...
    EVT_FALLING: int
    EVT_RISING: int
    EVT_RISING_FALLING: int
    IRQ_FALLING: int
    IRQ_RISING: int
    IRQ_RISING_FALLING: int
    def disable(self, *args, **kwargs) -> Any: ...
    def enable(self, *args, **kwargs) -> Any: ...
    def line(self, *args, **kwargs) -> Any: ...
    def regs(self, *args, **kwargs) -> Any: ...
    def swint(self, *args, **kwargs) -> Any: ...

class Flash:
    def __init__(self, *argv, **kwargs) -> None: ...
    def ioctl(self, *args, **kwargs) -> Any: ...
    def readblocks(self, *args, **kwargs) -> Any: ...
    def writeblocks(self, *args, **kwargs) -> Any: ...

class I2C:
    def __init__(self, *argv, **kwargs) -> None: ...
    def send(self, *args, **kwargs) -> Any: ...
    CONTROLLER: int
    MASTER: int
    PERIPHERAL: int
    SLAVE: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def is_ready(self, *args, **kwargs) -> Any: ...
    def mem_read(self, *args, **kwargs) -> Any: ...
    def mem_write(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...

class LCD:
    def __init__(self, *argv, **kwargs) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def command(self, *args, **kwargs) -> Any: ...
    def contrast(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def light(self, *args, **kwargs) -> Any: ...
    def pixel(self, *args, **kwargs) -> Any: ...
    def show(self, *args, **kwargs) -> Any: ...
    def text(self, *args, **kwargs) -> Any: ...

class LED:
    def __init__(self, *argv, **kwargs) -> None: ...
    def intensity(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...
    def toggle(self, *args, **kwargs) -> Any: ...

class Pin:
    def __init__(self, *argv, **kwargs) -> None: ...
    @classmethod
    def dict(cls, *args, **kwargs) -> Any: ...
    def value(self, *args, **kwargs) -> Any: ...
    AF1_TIM1: int
    AF1_TIM2: int
    AF2_TIM3: int
    AF2_TIM4: int
    AF2_TIM5: int
    AF3_TIM10: int
    AF3_TIM11: int
    AF3_TIM8: int
    AF3_TIM9: int
    AF4_I2C1: int
    AF4_I2C2: int
    AF5_I2S2: int
    AF5_SPI1: int
    AF5_SPI2: int
    AF6_I2S2: int
    AF7_USART1: int
    AF7_USART2: int
    AF7_USART3: int
    AF8_UART4: int
    AF8_USART6: int
    AF9_CAN1: int
    AF9_CAN2: int
    AF9_TIM12: int
    AF9_TIM13: int
    AF9_TIM14: int
    AF_OD: int
    AF_PP: int
    ALT: int
    ALT_OPEN_DRAIN: int
    ANALOG: int
    IN: int
    IRQ_FALLING: int
    IRQ_RISING: int
    OPEN_DRAIN: int
    OUT: int
    OUT_OD: int
    OUT_PP: int
    PULL_DOWN: int
    PULL_NONE: int
    PULL_UP: int
    def af(self, *args, **kwargs) -> Any: ...
    def af_list(self, *args, **kwargs) -> Any: ...
    class board:
        def __init__(self, *argv, **kwargs) -> None: ...
        LED_BLUE: Any
        LED_GREEN: Any
        LED_RED: Any
        LED_YELLOW: Any
        MMA_AVDD: Any
        MMA_INT: Any
        SD: Any
        SD_CK: Any
        SD_CMD: Any
        SD_D0: Any
        SD_D1: Any
        SD_D2: Any
        SD_D3: Any
        SD_SW: Any
        SW: Any
        USB_DM: Any
        USB_DP: Any
        USB_ID: Any
        USB_VBUS: Any
        X1: Any
        X10: Any
        X11: Any
        X12: Any
        X17: Any
        X18: Any
        X19: Any
        X2: Any
        X20: Any
        X21: Any
        X22: Any
        X3: Any
        X4: Any
        X5: Any
        X6: Any
        X7: Any
        X8: Any
        X9: Any
        Y1: Any
        Y10: Any
        Y11: Any
        Y12: Any
        Y2: Any
        Y3: Any
        Y4: Any
        Y5: Any
        Y6: Any
        Y7: Any
        Y8: Any
        Y9: Any
    class cpu:
        def __init__(self, *argv, **kwargs) -> None: ...
        A0: Any
        A1: Any
        A10: Any
        A11: Any
        A12: Any
        A13: Any
        A14: Any
        A15: Any
        A2: Any
        A3: Any
        A4: Any
        A5: Any
        A6: Any
        A7: Any
        A8: Any
        A9: Any
        B0: Any
        B1: Any
        B10: Any
        B11: Any
        B12: Any
        B13: Any
        B14: Any
        B15: Any
        B2: Any
        B3: Any
        B4: Any
        B5: Any
        B6: Any
        B7: Any
        B8: Any
        B9: Any
        C0: Any
        C1: Any
        C10: Any
        C11: Any
        C12: Any
        C13: Any
        C2: Any
        C3: Any
        C4: Any
        C5: Any
        C6: Any
        C7: Any
        C8: Any
        C9: Any
        D2: Any
    @classmethod
    def debug(cls, *args, **kwargs) -> Any: ...
    def gpio(self, *args, **kwargs) -> Any: ...
    def high(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def low(self, *args, **kwargs) -> Any: ...
    @classmethod
    def mapper(cls, *args, **kwargs) -> Any: ...
    def mode(self, *args, **kwargs) -> Any: ...
    def name(self, *args, **kwargs) -> Any: ...
    def names(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...
    def pin(self, *args, **kwargs) -> Any: ...
    def port(self, *args, **kwargs) -> Any: ...
    def pull(self, *args, **kwargs) -> Any: ...

class SDCard:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def ioctl(self, *args, **kwargs) -> Any: ...
    def power(self, *args, **kwargs) -> Any: ...
    def present(self, *args, **kwargs) -> Any: ...
    def readblocks(self, *args, **kwargs) -> Any: ...
    def writeblocks(self, *args, **kwargs) -> Any: ...

class SPI:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def send(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CONTROLLER: int
    LSB: int
    MASTER: int
    MSB: int
    PERIPHERAL: int
    SLAVE: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def send_recv(self, *args, **kwargs) -> Any: ...
    def write_readinto(self, *args, **kwargs) -> Any: ...

class Servo:
    def __init__(self, *argv, **kwargs) -> None: ...
    def angle(self, *args, **kwargs) -> Any: ...
    def calibration(self, *args, **kwargs) -> Any: ...
    def pulse_width(self, *args, **kwargs) -> Any: ...
    def speed(self, *args, **kwargs) -> Any: ...

class Switch:
    def __init__(self, *argv, **kwargs) -> None: ...
    def value(self, *args, **kwargs) -> Any: ...
    def callback(self, *args, **kwargs) -> Any: ...

class Timer:
    def __init__(self, *argv, **kwargs) -> None: ...
    BOTH: int
    BRK_HIGH: int
    BRK_LOW: int
    BRK_OFF: int
    CENTER: int
    DOWN: int
    ENC_A: int
    ENC_AB: int
    ENC_B: int
    FALLING: int
    HIGH: int
    IC: int
    LOW: int
    OC_ACTIVE: int
    OC_FORCED_ACTIVE: int
    OC_FORCED_INACTIVE: int
    OC_INACTIVE: int
    OC_TIMING: int
    OC_TOGGLE: int
    PWM: int
    PWM_INVERTED: int
    RISING: int
    UP: int
    def callback(self, *args, **kwargs) -> Any: ...
    def channel(self, *args, **kwargs) -> Any: ...
    def counter(self, *args, **kwargs) -> Any: ...
    def deinit(self, *args, **kwargs) -> Any: ...
    def freq(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def period(self, *args, **kwargs) -> Any: ...
    def prescaler(self, *args, **kwargs) -> Any: ...
    def source_freq(self, *args, **kwargs) -> Any: ...

class UART:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CTS: int
    IRQ_RXIDLE: int
    RTS: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def readchar(self, *args, **kwargs) -> Any: ...
    def sendbreak(self, *args, **kwargs) -> Any: ...
    def writechar(self, *args, **kwargs) -> Any: ...

class USB_HID:
    def __init__(self, *argv, **kwargs) -> None: ...
    def send(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...

class USB_VCP:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def close(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def send(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CTS: int
    IRQ_RX: int
    RTS: int
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def isconnected(self, *args, **kwargs) -> Any: ...
    def readlines(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def setinterrupt(self, *args, **kwargs) -> Any: ...

def bootloader(*args, **kwargs) -> Any: ...
def country(*args, **kwargs) -> Any: ...
def delay(*args, **kwargs) -> Any: ...
def dht_readinto(*args, **kwargs) -> Any: ...
def disable_irq(*args, **kwargs) -> Any: ...
def elapsed_micros(*args, **kwargs) -> Any: ...
def elapsed_millis(*args, **kwargs) -> Any: ...
def enable_irq(*args, **kwargs) -> Any: ...
def fault_debug(*args, **kwargs) -> Any: ...
def freq(*args, **kwargs) -> Any: ...
def hard_reset(*args, **kwargs) -> Any: ...
def have_cdc(*args, **kwargs) -> Any: ...
def hid(*args, **kwargs) -> Any: ...

hid_keyboard: tuple
hid_mouse: tuple

def info(*args, **kwargs) -> Any: ...
def micros(*args, **kwargs) -> Any: ...
def millis(*args, **kwargs) -> Any: ...
def mount(*args, **kwargs) -> Any: ...
def pwm(*args, **kwargs) -> Any: ...
def repl_info(*args, **kwargs) -> Any: ...
def repl_uart(*args, **kwargs) -> Any: ...
def rng(*args, **kwargs) -> Any: ...
def servo(*args, **kwargs) -> Any: ...
def standby(*args, **kwargs) -> Any: ...
def sync(*args, **kwargs) -> Any: ...
def udelay(*args, **kwargs) -> Any: ...
def unique_id(*args, **kwargs) -> Any: ...
def usb_mode(*args, **kwargs) -> Any: ...
def wfi(*args, **kwargs) -> Any: ...



"""
Module: 'math' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


def pow(*args, **kwargs) -> Any:
    ...


def acos(*args, **kwargs) -> Any:
    ...


def acosh(*args, **kwargs) -> Any:
    ...


def asin(*args, **kwargs) -> Any:
    ...


def asinh(*args, **kwargs) -> Any:
    ...


def atan(*args, **kwargs) -> Any:
    ...


def atan2(*args, **kwargs) -> Any:
    ...


def atanh(*args, **kwargs) -> Any:
    ...


def ceil(*args, **kwargs) -> Any:
    ...


def copysign(*args, **kwargs) -> Any:
    ...


def cos(*args, **kwargs) -> Any:
    ...


def cosh(*args, **kwargs) -> Any:
    ...


def degrees(*args, **kwargs) -> Any:
    ...


e = 2.718282  # type: float


def erf(*args, **kwargs) -> Any:
    ...


def erfc(*args, **kwargs) -> Any:
    ...


def exp(*args, **kwargs) -> Any:
    ...


def expm1(*args, **kwargs) -> Any:
    ...


def fabs(*args, **kwargs) -> Any:
    ...


def factorial(*args, **kwargs) -> Any:
    ...


def floor(*args, **kwargs) -> Any:
    ...


def fmod(*args, **kwargs) -> Any:
    ...


def frexp(*args, **kwargs) -> Any:
    ...


def gamma(*args, **kwargs) -> Any:
    ...


def isclose(*args, **kwargs) -> Any:
    ...


def isfinite(*args, **kwargs) -> Any:
    ...


def isinf(*args, **kwargs) -> Any:
    ...


def isnan(*args, **kwargs) -> Any:
    ...


def ldexp(*args, **kwargs) -> Any:
    ...


def lgamma(*args, **kwargs) -> Any:
    ...


def log(*args, **kwargs) -> Any:
    ...


def log10(*args, **kwargs) -> Any:
    ...


def log2(*args, **kwargs) -> Any:
    ...


def modf(*args, **kwargs) -> Any:
    ...


pi = 3.141593  # type: float


def radians(*args, **kwargs) -> Any:
    ...


def sin(*args, **kwargs) -> Any:
    ...


def sinh(*args, **kwargs) -> Any:
    ...


def sqrt(*args, **kwargs) -> Any:
    ...


def tan(*args, **kwargs) -> Any:
    ...


def tanh(*args, **kwargs) -> Any:
    ...


def trunc(*args, **kwargs) -> Any:
    ...



from typing import Any

class OrderedDict:
    def __init__(self, *argv, **kwargs) -> None: ...
    def clear(self, *args, **kwargs) -> Any: ...
    def copy(self, *args, **kwargs) -> Any: ...
    def get(self, *args, **kwargs) -> Any: ...
    def items(self, *args, **kwargs) -> Any: ...
    def keys(self, *args, **kwargs) -> Any: ...
    def pop(self, *args, **kwargs) -> Any: ...
    def popitem(self, *args, **kwargs) -> Any: ...
    def setdefault(self, *args, **kwargs) -> Any: ...
    def update(self, *args, **kwargs) -> Any: ...
    def values(self, *args, **kwargs) -> Any: ...
    @classmethod
    def fromkeys(cls, *args, **kwargs) -> Any: ...

class deque:
    def __init__(self, *argv, **kwargs) -> None: ...
    def append(self, *args, **kwargs) -> Any: ...
    def popleft(self, *args, **kwargs) -> Any: ...

def namedtuple(*args, **kwargs) -> Any: ...



from typing import Any

def choice(*args, **kwargs) -> Any: ...
def getrandbits(*args, **kwargs) -> Any: ...
def randint(*args, **kwargs) -> Any: ...
def random(*args, **kwargs) -> Any: ...
def randrange(*args, **kwargs) -> Any: ...
def seed(*args, **kwargs) -> Any: ...
def uniform(*args, **kwargs) -> Any: ...



"""
Module: 'builtins' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


class ArithmeticError(Exception):
    """"""


class AssertionError(Exception):
    """"""


class AttributeError(Exception):
    """"""


class EOFError(Exception):
    """"""


Ellipsis: Any  ## <class ''> = Ellipsis


class GeneratorExit:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class ImportError(Exception):
    """"""


class IndentationError(Exception):
    """"""


class IndexError(Exception):
    """"""


class KeyError(Exception):
    """"""


class KeyboardInterrupt(Exception):
    """"""


class LookupError(Exception):
    """"""


class MemoryError(Exception):
    """"""


class NameError(Exception):
    """"""


class NotImplementedError(Exception):
    """"""


class OSError(Exception):
    """"""


class OverflowError(Exception):
    """"""


class RuntimeError(Exception):
    """"""


class StopIteration(Exception):
    """"""


class SyntaxError(Exception):
    """"""


class SystemExit(Exception):
    """"""


class TypeError(Exception):
    """"""


class ValueError(Exception):
    """"""


class ZeroDivisionError(Exception):
    """"""


def abs(*args, **kwargs) -> Any:
    ...


def all(*args, **kwargs) -> Any:
    ...


def any(*args, **kwargs) -> Any:
    ...


class bool:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class bytearray:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def append(self, *args, **kwargs) -> Any:
        ...

    def extend(self, *args, **kwargs) -> Any:
        ...

    def decode(self, *args, **kwargs) -> Any:
        ...


class bytes:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def count(self, *args, **kwargs) -> Any:
        ...

    def endswith(self, *args, **kwargs) -> Any:
        ...

    def find(self, *args, **kwargs) -> Any:
        ...

    def format(self, *args, **kwargs) -> Any:
        ...

    def index(self, *args, **kwargs) -> Any:
        ...

    def isalpha(self, *args, **kwargs) -> Any:
        ...

    def isdigit(self, *args, **kwargs) -> Any:
        ...

    def islower(self, *args, **kwargs) -> Any:
        ...

    def isspace(self, *args, **kwargs) -> Any:
        ...

    def isupper(self, *args, **kwargs) -> Any:
        ...

    def join(self, *args, **kwargs) -> Any:
        ...

    def lower(self, *args, **kwargs) -> Any:
        ...

    def lstrip(self, *args, **kwargs) -> Any:
        ...

    def replace(self, *args, **kwargs) -> Any:
        ...

    def rfind(self, *args, **kwargs) -> Any:
        ...

    def rindex(self, *args, **kwargs) -> Any:
        ...

    def rsplit(self, *args, **kwargs) -> Any:
        ...

    def rstrip(self, *args, **kwargs) -> Any:
        ...

    def split(self, *args, **kwargs) -> Any:
        ...

    def startswith(self, *args, **kwargs) -> Any:
        ...

    def strip(self, *args, **kwargs) -> Any:
        ...

    def upper(self, *args, **kwargs) -> Any:
        ...

    def center(self, *args, **kwargs) -> Any:
        ...

    def decode(self, *args, **kwargs) -> Any:
        ...

    def partition(self, *args, **kwargs) -> Any:
        ...

    def rpartition(self, *args, **kwargs) -> Any:
        ...

    def splitlines(self, *args, **kwargs) -> Any:
        ...


def callable(*args, **kwargs) -> Any:
    ...


def chr(*args, **kwargs) -> Any:
    ...


class dict:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def clear(self, *args, **kwargs) -> Any:
        ...

    def copy(self, *args, **kwargs) -> Any:
        ...

    def get(self, *args, **kwargs) -> Any:
        ...

    def items(self, *args, **kwargs) -> Any:
        ...

    def keys(self, *args, **kwargs) -> Any:
        ...

    def pop(self, *args, **kwargs) -> Any:
        ...

    def popitem(self, *args, **kwargs) -> Any:
        ...

    def setdefault(self, *args, **kwargs) -> Any:
        ...

    def update(self, *args, **kwargs) -> Any:
        ...

    def values(self, *args, **kwargs) -> Any:
        ...

    @classmethod
    def fromkeys(cls, *args, **kwargs) -> Any:
        ...


def dir(*args, **kwargs) -> Any:
    ...


def divmod(*args, **kwargs) -> Any:
    ...


def eval(*args, **kwargs) -> Any:
    ...


def exec(*args, **kwargs) -> Any:
    ...


def getattr(*args, **kwargs) -> Any:
    ...


def globals(*args, **kwargs) -> Any:
    ...


def hasattr(*args, **kwargs) -> Any:
    ...


def hash(*args, **kwargs) -> Any:
    ...


def id(*args, **kwargs) -> Any:
    ...


class int:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    @classmethod
    def from_bytes(cls, *args, **kwargs) -> Any:
        ...

    def to_bytes(self, *args, **kwargs) -> Any:
        ...


def isinstance(*args, **kwargs) -> Any:
    ...


def issubclass(*args, **kwargs) -> Any:
    ...


def iter(*args, **kwargs) -> Any:
    ...


def len(*args, **kwargs) -> Any:
    ...


class list:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def append(self, *args, **kwargs) -> Any:
        ...

    def clear(self, *args, **kwargs) -> Any:
        ...

    def copy(self, *args, **kwargs) -> Any:
        ...

    def count(self, *args, **kwargs) -> Any:
        ...

    def extend(self, *args, **kwargs) -> Any:
        ...

    def index(self, *args, **kwargs) -> Any:
        ...

    def insert(self, *args, **kwargs) -> Any:
        ...

    def pop(self, *args, **kwargs) -> Any:
        ...

    def remove(self, *args, **kwargs) -> Any:
        ...

    def reverse(self, *args, **kwargs) -> Any:
        ...

    def sort(self, *args, **kwargs) -> Any:
        ...


def locals(*args, **kwargs) -> Any:
    ...


class map:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


def next(*args, **kwargs) -> Any:
    ...


class object:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


def open(*args, **kwargs) -> Any:
    ...


def ord(*args, **kwargs) -> Any:
    ...


def pow(*args, **kwargs) -> Any:
    ...


def print(*args, **kwargs) -> Any:
    ...


class range:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


def repr(*args, **kwargs) -> Any:
    ...


def round(*args, **kwargs) -> Any:
    ...


class set:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def clear(self, *args, **kwargs) -> Any:
        ...

    def copy(self, *args, **kwargs) -> Any:
        ...

    def pop(self, *args, **kwargs) -> Any:
        ...

    def remove(self, *args, **kwargs) -> Any:
        ...

    def update(self, *args, **kwargs) -> Any:
        ...

    def add(self, *args, **kwargs) -> Any:
        ...

    def difference(self, *args, **kwargs) -> Any:
        ...

    def difference_update(self, *args, **kwargs) -> Any:
        ...

    def discard(self, *args, **kwargs) -> Any:
        ...

    def intersection(self, *args, **kwargs) -> Any:
        ...

    def intersection_update(self, *args, **kwargs) -> Any:
        ...

    def isdisjoint(self, *args, **kwargs) -> Any:
        ...

    def issubset(self, *args, **kwargs) -> Any:
        ...

    def issuperset(self, *args, **kwargs) -> Any:
        ...

    def symmetric_difference(self, *args, **kwargs) -> Any:
        ...

    def symmetric_difference_update(self, *args, **kwargs) -> Any:
        ...

    def union(self, *args, **kwargs) -> Any:
        ...


def setattr(*args, **kwargs) -> Any:
    ...


def sorted(*args, **kwargs) -> Any:
    ...


class str:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def count(self, *args, **kwargs) -> Any:
        ...

    def endswith(self, *args, **kwargs) -> Any:
        ...

    def find(self, *args, **kwargs) -> Any:
        ...

    def format(self, *args, **kwargs) -> Any:
        ...

    def index(self, *args, **kwargs) -> Any:
        ...

    def isalpha(self, *args, **kwargs) -> Any:
        ...

    def isdigit(self, *args, **kwargs) -> Any:
        ...

    def islower(self, *args, **kwargs) -> Any:
        ...

    def isspace(self, *args, **kwargs) -> Any:
        ...

    def isupper(self, *args, **kwargs) -> Any:
        ...

    def join(self, *args, **kwargs) -> Any:
        ...

    def lower(self, *args, **kwargs) -> Any:
        ...

    def lstrip(self, *args, **kwargs) -> Any:
        ...

    def replace(self, *args, **kwargs) -> Any:
        ...

    def rfind(self, *args, **kwargs) -> Any:
        ...

    def rindex(self, *args, **kwargs) -> Any:
        ...

    def rsplit(self, *args, **kwargs) -> Any:
        ...

    def rstrip(self, *args, **kwargs) -> Any:
        ...

    def split(self, *args, **kwargs) -> Any:
        ...

    def startswith(self, *args, **kwargs) -> Any:
        ...

    def strip(self, *args, **kwargs) -> Any:
        ...

    def upper(self, *args, **kwargs) -> Any:
        ...

    def center(self, *args, **kwargs) -> Any:
        ...

    def encode(self, *args, **kwargs) -> Any:
        ...

    def partition(self, *args, **kwargs) -> Any:
        ...

    def rpartition(self, *args, **kwargs) -> Any:
        ...

    def splitlines(self, *args, **kwargs) -> Any:
        ...


def sum(*args, **kwargs) -> Any:
    ...


class super:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class tuple:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def count(self, *args, **kwargs) -> Any:
        ...

    def index(self, *args, **kwargs) -> Any:
        ...


class type:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class zip:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


NotImplemented: Any  ## <class ''> = NotImplemented


class StopAsyncIteration:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class UnicodeError(Exception):
    """"""


class ViperTypeError(Exception):
    """"""


def bin(*args, **kwargs) -> Any:
    ...


def compile(*args, **kwargs) -> Any:
    ...


class complex:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


def delattr(*args, **kwargs) -> Any:
    ...


class enumerate:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


def execfile(*args, **kwargs) -> Any:
    ...


class filter:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class float:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class frozenset:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def copy(self, *args, **kwargs) -> Any:
        ...

    def difference(self, *args, **kwargs) -> Any:
        ...

    def intersection(self, *args, **kwargs) -> Any:
        ...

    def isdisjoint(self, *args, **kwargs) -> Any:
        ...

    def issubset(self, *args, **kwargs) -> Any:
        ...

    def issuperset(self, *args, **kwargs) -> Any:
        ...

    def symmetric_difference(self, *args, **kwargs) -> Any:
        ...

    def union(self, *args, **kwargs) -> Any:
        ...


def help(*args, **kwargs) -> Any:
    ...


def hex(*args, **kwargs) -> Any:
    ...


def input(*args, **kwargs) -> Any:
    ...


def max(*args, **kwargs) -> Any:
    ...


class memoryview:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


def min(*args, **kwargs) -> Any:
    ...


def oct(*args, **kwargs) -> Any:
    ...


class property:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def deleter(self, *args, **kwargs) -> Any:
        ...

    def getter(self, *args, **kwargs) -> Any:
        ...

    def setter(self, *args, **kwargs) -> Any:
        ...


class reversed:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...


class slice:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...
